.header_upload{
    color: black;
    text-align: center;
    /* position: relative;
    right: 50px; */
}

.image{
    display: flex;
    max-height: 160px;
}

.img_div{
    width: 60%;
    height: 200px;
}

.plot{
    display: flex;
    max-height: 400px;
}

.plot_div{
    width: 60%;
    height: 420px;
}
